@@ -10,6 +10,7 @@ from .typing_compat import (
     get_args,
     get_origin,
     is_literal,
+    is_newtype,
     is_typeddict,
 )
 
@@ -19,11 +20,13 @@ __all__ = (
     # typing, typing_extensions or own backport
     "Any",
     "Dict",
+    "Generic",
     "Literal",
     "List",
     "Listx",
     "Mapping",
     "Optional",
+    "NewType",
     "NoneType",
     "Union",
     "Set",
@@ -31,9 +34,11 @@ __all__ = (
     "Tuple",
     "Tuplex",
     "Type",
+    "TypeVar",
     "TypedDict",
     "get_args",
     "get_origin",
     "is_literal",
+    "is_newtype",
     "is_typeddict",
 )
