@@ -1,38 +1,70 @@
 import collections.abc
-from typing import Any, Dict, List, Set, Union
+import sys
+from typing import Any, Callable, Dict, List, Set, Union, cast
 
 from .types import Listx, Tuplex
-from .typing_compat import TypedDict, get_args, get_origin, get_type_hints, is_literal, is_typeddict
-from .utils import OneOrManyTypes, TypeLike, lenient_isinstance, lenient_issubclass
+from .typing_compat import (
+    Literal,
+    NoneType,
+    OneOrManyTypes,
+    TypedDict,
+    TypeLike,
+    get_args,
+    get_origin,
+    get_type_hints,
+    is_generic,
+    is_literal,
+    is_newtype,
+    is_typeddict,
+)
 
-__all__ = ("isinstancex",)
+__all__ = ("isinstancex", "issubclassx")
 
 TYPED_DICT_EXTRA_KEY = "__extra__"
+NONE_TYPES = (None, NoneType, Literal[None])
+if sys.version_info < (3, 10):
+    UNION_TYPES = (Union,)
+else:
+    import types
+
+    UNION_TYPES = (Union, types.Union)
 
 
-def isinstancex(obj: Any, tp: OneOrManyTypes) -> bool:
-    try:
-        return _isinstancex(obj, tp)
-    except (AttributeError, TypeError):
-        return False
-
-
-def _isinstancex(obj: Any, tp: Any) -> bool:
+def _isinstancex(obj: Any, tp: TypeLike) -> bool:
     """Extend `isinstance` with `typing` types"""
     if tp is Any:
         return True
 
-    if lenient_isinstance(tp, tuple):
-        return any(isinstancex(obj, sub_tp) for sub_tp in tp)
+    while is_newtype(tp):
+        tp = tp.__supertype__
+
+    # https://www.python.org/dev/peps/pep-0484/#using-none
+    if obj is None and tp in NONE_TYPES:
+        return True
 
     origin = get_origin(tp)
 
-    # e.g. Union[str, int]
-    if origin is Union:
+    # convert
+    # - a plain dictionary to Dict or TypedDict
+    # - a plain list to Listx[...]
+    if origin is None:
+        if isinstance(tp, dict):
+            tp = {(TYPED_DICT_EXTRA_KEY if k is ... else k): v for k, v in tp.items()}
+            if len(tp) == 1 and not isinstancex(list(tp.keys())[0], str):
+                # tp is of form `{TypeLike: TypeLike}`
+                return _isinstancex(obj, Dict[list(tp.items())[0]])  # type: ignore
+            else:
+                # tp is of form `{'a': TypeLike, ...}`, `{...: TypeLike}`
+                return _isinstancex(obj, TypedDict("_TypedDict", tp))  # type: ignore
+        elif isinstance(tp, list):
+            return _isinstancex(obj, Listx[tuple(tp)])
+
+    # e.g. Union[str, int] (or str|int in 3.10)
+    if origin in UNION_TYPES:
         return isinstancex(obj, get_args(tp))
 
     # e.g. Dict[str, int]
-    if origin is dict:
+    elif origin is dict:
         if tp is Dict:
             tp = Dict[Any, Any]
         return isinstancex(obj, dict) and _is_valid_mapping(obj, tp)
@@ -59,13 +91,11 @@ def _isinstancex(obj: Any, tp: Any) -> bool:
 
     # e.g. Type[int]
     elif origin is type:
-        return lenient_issubclass(obj, get_args(tp))
+        return issubclassx(obj, get_args(tp))
 
     # e.g. TypedDict('Movie', {'name': str, 'year': int})
     elif is_typeddict(tp):
-        if not (isinstance(obj, dict) and all(isinstance(k, str) for k in obj)):
-            return False
-
+        tp = cast(TypedDict, tp)
         return _is_valid_typeddict(obj, tp)
 
     # e.g. Literal['Pika']
@@ -89,7 +119,49 @@ def _isinstancex(obj: Any, tp: Any) -> bool:
     elif tp is Tuplex:
         tp = tuple
 
-    return lenient_isinstance(obj, tp)
+    return isinstance(obj, tp)
+
+
+def _issubclassx(obj: Any, tp: TypeLike) -> bool:
+    if obj is tp:
+        return True
+
+    if is_generic(obj) and is_generic(tp):
+        obj_mother_class = get_origin(obj.__orig_bases__[0])
+        obj_mother_args = get_args(obj.__orig_bases__[0])
+
+        return issubclassx(obj_mother_class, get_origin(tp)) and all(
+            issubclassx(arg, get_args(tp)) for arg in obj_mother_args
+        )
+
+    return issubclass(obj, tp)
+
+
+def _safe_multi(f: Callable[[Any, TypeLike], bool]) -> Callable[[Any, OneOrManyTypes], bool]:
+    def safe_f_multi(obj: Any, tp: OneOrManyTypes) -> bool:
+        try:
+            if isinstance(tp, tuple):
+                return any(f(obj, sub_tp) for sub_tp in tp)
+            else:
+                return f(obj, tp)
+        except (AttributeError, TypeError):
+            return False
+
+    return safe_f_multi
+
+
+isinstancex = _safe_multi(_isinstancex)
+issubclassx = _safe_multi(_issubclassx)
+
+
+#######################################
+# get_args
+#######################################
+def _is_valid_mapping(obj: Any, tp: TypeLike) -> bool:
+    keys_type, values_type = get_args(tp)
+    return all(isinstancex(key, keys_type) for key in obj.keys()) and all(
+        isinstancex(value, values_type) for value in obj.values()
+    )
 
 
 def _is_valid_sequence(obj: Any, tp: TypeLike, *, is_list: bool) -> bool:
@@ -129,14 +201,7 @@ def _is_valid_sequence(obj: Any, tp: TypeLike, *, is_list: bool) -> bool:
         return expected_types[current_index:] in ((), (...,))
 
 
-def _is_valid_mapping(obj: Any, tp: TypeLike) -> bool:
-    keys_type, values_type = get_args(tp)
-    return all(isinstancex(key, keys_type) for key in obj.keys()) and all(
-        isinstancex(value, values_type) for value in obj.values()
-    )
-
-
-def _is_valid_typeddict(obj: Dict[str, Any], tp: TypedDict) -> bool:
+def _is_valid_typeddict(obj: Any, tp: TypedDict) -> bool:
     # ensure it's a dict that contains all the required keys but extra values are allowed
     resolved_annotations = get_type_hints(tp)
 
