@@ -5,21 +5,25 @@ for some methods / classes of the `typing` module
 import sys
 import typing as T
 
-from .utils import TypeLike, lenient_issubclass
-
 __all__ = (
     "Literal",
     "NoneType",
+    "OneOrManyTypes",
     "TypedDict",
+    "TypeLike",
     "get_args",
     "get_origin",
     "get_type_hints",
+    "is_generic",
     "is_literal",
+    "is_newtype",
     "is_typeddict",
 )
 
 
 NoneType = type(None)
+TypeLike = T.Union[T.Type[T.Any], T.Union[T.Any]]
+OneOrManyTypes = T.Union[TypeLike, T.Tuple[TypeLike, ...]]
 
 
 #######################################
@@ -37,12 +41,12 @@ else:
 def get_args(tp: TypeLike) -> T.Tuple[T.Any, ...]:
     if sys.version_info >= (3, 10):
         return T_get_args(tp)
-    # Handle nested literals (see https://www.python.org/dev/peps/pep-0586)
     else:
+        # Handle nested literals (see https://www.python.org/dev/peps/pep-0586)
         if is_literal(tp):
             return _get_all_literal_values(tp)
 
-        return T_get_args(tp)
+        return T_get_args(tp) or ()
 
 
 #######################################
@@ -74,12 +78,20 @@ else:
         }
 
         origin = getattr(tp, "__origin__", None)
+        # change `List[Tuple[~T, ~T]]` into `List`
+        origin = getattr(origin, "_gorg", origin)
         return typing_to_builtin_map.get(origin, origin)
 
 
 def get_origin(tp: TypeLike) -> T.Optional[TypeLike]:
-    # Python 3.7+
-    if sys.version_info >= (3, 7):
+    # Python 3.8+
+    if sys.version_info >= (3, 8):
+        return T_get_origin(tp)
+
+    # Python 3.7
+    elif sys.version_info >= (3, 7):
+        if tp is T.Generic:
+            return T.Generic
         return T_get_origin(tp)
 
     # Python 3.6
@@ -87,6 +99,9 @@ def get_origin(tp: TypeLike) -> T.Optional[TypeLike]:
         if is_literal(tp):
             return Literal
 
+        elif tp is T.Generic:
+            return T.Generic
+
         return T_get_origin(tp)
 
 
@@ -150,7 +165,7 @@ def is_typeddict(tp: TypeLike) -> bool:
 
     # Python 3.6 to Python 3.9
     else:
-        return lenient_issubclass(tp, dict) and hasattr(tp, "__annotations__")
+        return isinstance(tp, type) and issubclass(tp, dict) and hasattr(tp, "__annotations__")
 
 
 #######################################
@@ -185,3 +200,23 @@ def _get_all_literal_values(tp: TypeLike) -> T.Tuple[T.Any, ...]:
 
     literal_values = _get_literal_values(tp)
     return tuple(x for v in literal_values for x in _get_all_literal_values(v))
+
+
+#######################################
+# NewType
+#######################################
+TestType = T.NewType("TestType", str)
+
+
+def is_newtype(tp: TypeLike) -> bool:
+    """
+    Check if a type is a `NewType`
+    """
+    return tp.__class__ is TestType.__class__
+
+
+#######################################
+# Generic
+#######################################
+def is_generic(tp: TypeLike) -> bool:
+    return hasattr(tp, "__parameters__")
